<?php

if ( !class_exists( 'customizeController' ) ) {

class customizeController extends pwsController_1_0 {
	
	public function __construct( $pluginSettings ) {

		
		$this->config = $pluginSettings;

		$this->stylesheets = Array(
			//'customize_styles' => 'customize_styles.css'
		);

		$this->javascripts = Array(
			//'customize_js' => 'customize_script.js'
		);
		
		$this->default_options = Array( 
					'shipping' => Array(
						'link_target' => '_self',
						'link_title' => 'View shipping rate table',
						'zones' => Array( )
						)
					);

		extract( $pluginSettings['constants'] );

		$title = ucfirst( $plugin_menu_display_name );
		$this->menus = Array(
			Array(
				'type' => 'sub',
				'settingspage' => TRUE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'main',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'shipping',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'emails',
				'iconUrl' => '',
				'position' => '100'
			),
			Array(
				'type' => 'detached',
				'settingspage' => FALSE,
				'pageTitle' => $title,
				'menuTitle' => 'Customize',
				'capability' => 'administrator',
				'menuSlug' => 'misc',
				'iconUrl' => '',
				'position' => '100'
			)
		);
		
		parent::__construct( $pluginSettings );

		# Shipping
		add_filter( 'eshop_rename_ship_zone', Array( $this, 'custom_shipping_zones' ) );
		add_filter( 'eShopCheckoutLinksAttr', Array( $this, 'shipping_link_attributes' ) );

		# Emails
		add_filter( 'eshop_gateway_details_email', Array( $this, 'extra_admin_emails' ) );
		add_action( 'eshop_send_customer_email', Array( $this, 'copy_customer_email' ), 10, 4 );

		# Misc
		add_filter( 'gettext', Array( $this, 'filter_eshop_text' ), 10, 3 );
	}

	public function main( ) {

	    return null;
	}
	
	public function shipping( ) {

		if ( isset( $_POST['shipping_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$_POST['shipping']['zones'] = array_filter( $_POST['shipping']['zones'] );
			$this->options['shipping'] = $_POST['shipping'];
			$this->saveOptions( $this->options );
		}

		$this->view = $this->options['shipping'];

	}
	
	public function emails( ) {

		if ( isset( $_POST['emails_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$this->options['emails'] = $_POST['emails'];
			$this->saveOptions( $this->options );
		}
		
		$this->view = $this->options['emails'];

	}
	
	public function misc( ) {

		if ( isset( $_POST['misc_submit'] ) && $this->nonceValid( $_POST['nonce'] ) ) {
			$this->options['misc'] = $_POST['misc'];
			$this->saveOptions( $this->options );
		}
		
		$this->view = $this->options['misc'];

	}
	
	public function filter_eshop_text( $translation, $text, $domain ) {

		if ( $domain != 'eshop' ) return $translation;

		$translations = &get_translations_for_domain( 'eshop' );

		if ( is_array( $this->options['misc'] ) ) extract( $this->options['misc'] );
		
		if ( isset( $replace_at_symbol ) ) {

			# This works on a product page
			if ( $text == '@ %1$s%2$s' ) {
				return $translations->translate( $replace_at_symbol . ' %1$s%2$s' );
			}

			# This is the example string in eShop wiki - not sure if it's redundant or not, so leaving it in for now
			if ( $text == '%1$s @ %2$s%3$s' ) {
				return $translations->translate( '%1$s ' . $replace_at_symbol . ' %2$s%3$s' );
			}

		}

		return $translation;

	}

	public function extra_admin_emails( $addresses ) {
		
		if ( empty( $this->options['emails']['admin_recipients'] ) ) return $addresses;

		if ( $this->options['emails']['admin_replace'] ) {
			return explode( ',', $this->options['emails']['admin_recipients'] );
		} else {
			return array_merge( $addresses, explode( ',', $this->options['emails']['admin_recipients'] ) );
		}

	}	

	public function copy_customer_email( $subject, $body, $headers, $array ) {
	
		if ( empty( $this->options['emails']['customer_copy_recipients'] ) ) return;
		
		$recipients = $this->options['emails']['customer_copy_recipients'];

		wp_mail( $recipients, $subject, $body, $headers );

	}

	public function custom_shipping_zones( $zones ) {

		return $this->options['shipping']['zones'];

	}
	
	public function shipping_link_attributes( ) {

		return "target='{$this->options['shipping']['link_target']}' title='{$this->options['shipping']['link_title']}'";

	}	

}//end class
}//end if
